==> pmml-model-gwt-1.5.12-sources.jar: org/dmg/pmml/general_regression/PCovCell.java <==

package org.dmg.pmml.general_regression;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonRootName;
import org.dmg.pmml.Extension;
import org.dmg.pmml.HasExtensions;
import org.dmg.pmml.Visitor;
import org.dmg.pmml.VisitorAction;
import org.dmg.pmml.adapters.ObjectAdapter;
import org.dmg.pmml.adapters.RealNumberAdapter;
import org.jpmml.model.annotations.ValueConstructor;

@XmlRootElement(name = "PCovCell", namespace = "http://www.dmg.org/PMML-4_4")
@XmlType(name = "", propOrder = {
    "extensions"
})
@JsonRootName("PCovCell")
@JsonPropertyOrder({
    "pRow",
    "pCol",
    "tRow",
    "tCol",
    "value",
    "targetCategory",
    "extensions"
})
public class PCovCell
    extends org.dmg.pmml.PMMLObject
    implements HasExtensions<PCovCell>
{

    @XmlAttribute(name = "pRow", required = true)
    @JsonProperty("pRow")
    private String pRow;
    @XmlAttribute(name = "pCol", required = true)
    @JsonProperty("pCol")
    private String pCol;
    @XmlAttribute(name = "tRow")
    @JsonProperty("tRow")
    private String tRow;
    @XmlAttribute(name = "tCol")
    @JsonProperty("tCol")
    private String tCol;
    @XmlAttribute(name = "value", required = true)
    @XmlJavaTypeAdapter(RealNumberAdapter.class)
    @JsonProperty("value")
    private Number value;
    @XmlAttribute(name = "targetCategory")
    @XmlJavaTypeAdapter(ObjectAdapter.class)
    @XmlSchemaType(name = "anySimpleType")
    @JsonProperty("targetCategory")
    private Object targetCategory;
    @XmlElement(name = "Extension", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("Extension")
    private List<Extension> extensions;
    private final static long serialVersionUID = 67371267L;

    public PCovCell() {
    }

    @ValueConstructor
    public PCovCell(
        @org.jpmml.model.annotations.Property("pRow")
        String pRow,
        @org.jpmml.model.annotations.Property("pCol")
        String pCol,
        @org.jpmml.model.annotations.Property("value")
        Number value) {
        this.pRow = pRow;
        this.pCol = pCol;
        this.value = value;
    }

    public String getPRow() {
        return pRow;
    }

    public PCovCell setPRow(
        @org.jpmml.model.annotations.Property("pRow")
        String pRow) {
        this.pRow = pRow;
        return this;
    }

    public String getPCol() {
        return pCol;
    }

    public PCovCell setPCol(
        @org.jpmml.model.annotations.Property("pCol")
        String pCol) {
        this.pCol = pCol;
        return this;
    }

    public String getTRow() {
        return tRow;
    }

    public PCovCell setTRow(
        @org.jpmml.model.annotations.Property("tRow")
        String tRow) {
        this.tRow = tRow;
        return this;
    }

    public String getTCol() {
        return tCol;
    }

    public PCovCell setTCol(
        @org.jpmml.model.annotations.Property("tCol")
        String tCol) {
        this.tCol = tCol;
        return this;
    }

    public Number getValue() {
        return value;
    }

    public PCovCell setValue(
        @org.jpmml.model.annotations.Property("value")
        Number value) {
        this.value = value;
        return this;
    }

    public Object getTargetCategory() {
        return targetCategory;
    }

    public PCovCell setTargetCategory(
        @org.jpmml.model.annotations.Property("targetCategory")
        Object targetCategory) {
        this.targetCategory = targetCategory;
        return this;
    }

    @Override
    public boolean hasExtensions() {
        return ((this.extensions!= null)&&(this.extensions.size()> 0));
    }

    @Override
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    @Override
    public PCovCell addExtensions(Extension... extensions) {
        getExtensions().addAll(Arrays.asList(extensions));
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            if ((status == VisitorAction.CONTINUE)&&hasExtensions()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getExtensions());
            }
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}

==> pmml-model-gwt-1.6.2-sources.jar: org/dmg/pmml/general_regression/PCovCell.java <==

package org.dmg.pmml.general_regression;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonRootName;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlSchemaType;
import jakarta.xml.bind.annotation.XmlType;
import jakarta.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import org.dmg.pmml.Extension;
import org.dmg.pmml.HasExtensions;
import org.dmg.pmml.Visitor;
import org.dmg.pmml.VisitorAction;
import org.dmg.pmml.adapters.ObjectAdapter;
import org.dmg.pmml.adapters.RealNumberAdapter;
import org.jpmml.model.MissingAttributeException;
import org.jpmml.model.annotations.ValueConstructor;

@XmlRootElement(name = "PCovCell", namespace = "http://www.dmg.org/PMML-4_4")
@XmlType(name = "", propOrder = {
    "extensions"
})
@JsonRootName("PCovCell")
@JsonPropertyOrder({
    "pRow",
    "pCol",
    "tRow",
    "tCol",
    "value",
    "targetCategory",
    "extensions"
})
public class PCovCell
    extends org.dmg.pmml.PMMLObject
    implements HasExtensions<PCovCell>
{

    @XmlAttribute(name = "pRow", required = true)
    @JsonProperty("pRow")
    private String pRow;
    @XmlAttribute(name = "pCol", required = true)
    @JsonProperty("pCol")
    private String pCol;
    @XmlAttribute(name = "tRow")
    @JsonProperty("tRow")
    private String tRow;
    @XmlAttribute(name = "tCol")
    @JsonProperty("tCol")
    private String tCol;
    @XmlAttribute(name = "value", required = true)
    @XmlJavaTypeAdapter(RealNumberAdapter.class)
    @JsonProperty("value")
    private Number value;
    @XmlAttribute(name = "targetCategory")
    @XmlJavaTypeAdapter(ObjectAdapter.class)
    @XmlSchemaType(name = "anySimpleType")
    @JsonProperty("targetCategory")
    private Object targetCategory;
    @XmlElement(name = "Extension", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("Extension")
    private List<Extension> extensions;
    private final static long serialVersionUID = 67371269L;

    public PCovCell() {
    }

    @ValueConstructor
    public PCovCell(
        @org.jpmml.model.annotations.Property("pRow")
        String pRow,
        @org.jpmml.model.annotations.Property("pCol")
        String pCol,
        @org.jpmml.model.annotations.Property("value")
        Number value) {
        this.pRow = pRow;
        this.pCol = pCol;
        this.value = value;
    }

    public String requirePRow() {
        if (this.pRow == null) {
            throw new MissingAttributeException(this, PMMLAttributes.PCOVCELL_PROW);
        }
        return this.pRow;
    }

    public String getPRow() {
        return pRow;
    }

    public PCovCell setPRow(
        @org.jpmml.model.annotations.Property("pRow")
        String pRow) {
        this.pRow = pRow;
        return this;
    }

    public String requirePCol() {
        if (this.pCol == null) {
            throw new MissingAttributeException(this, PMMLAttributes.PCOVCELL_PCOL);
        }
        return this.pCol;
    }

    public String getPCol() {
        return pCol;
    }

    public PCovCell setPCol(
        @org.jpmml.model.annotations.Property("pCol")
        String pCol) {
        this.pCol = pCol;
        return this;
    }

    public String getTRow() {
        return tRow;
    }

    public PCovCell setTRow(
        @org.jpmml.model.annotations.Property("tRow")
        String tRow) {
        this.tRow = tRow;
        return this;
    }

    public String getTCol() {
        return tCol;
    }

    public PCovCell setTCol(
        @org.jpmml.model.annotations.Property("tCol")
        String tCol) {
        this.tCol = tCol;
        return this;
    }

    public Number requireValue() {
        if (this.value == null) {
            throw new MissingAttributeException(this, PMMLAttributes.PCOVCELL_VALUE);
        }
        return this.value;
    }

    public Number getValue() {
        return value;
    }

    public PCovCell setValue(
        @org.jpmml.model.annotations.Property("value")
        Number value) {
        this.value = value;
        return this;
    }

    public Object getTargetCategory() {
        return targetCategory;
    }

    public PCovCell setTargetCategory(
        @org.jpmml.model.annotations.Property("targetCategory")
        Object targetCategory) {
        this.targetCategory = targetCategory;
        return this;
    }

    @Override
    public boolean hasExtensions() {
        return ((this.extensions!= null)&&(!this.extensions.isEmpty()));
    }

    @Override
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    @Override
    public PCovCell addExtensions(Extension... extensions) {
        getExtensions().addAll(Arrays.asList(extensions));
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            if ((status == VisitorAction.CONTINUE)&&hasExtensions()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getExtensions());
            }
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}
